package com.foreverwin.mesnac.anomaly.mapper;

import com.foreverwin.mesnac.anomaly.dto.IntegrationLogDto;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;

/**
 * @Description TODO
 * @Author zhaojiawei
 * @Since 2021-08-23
 */
@Repository
public interface ReportMapper {

    List<IntegrationLogDto> findIntegrationLog(@Param("site")String site, @Param("param") Map<String,Object> map);

    List<Map<String, Object>> partsManufacturing(Map<String,Object> map);

    List<Map<String,Object>> surplusReturnTable(@Param("site")String site, @Param("locale")String locale,
                                           @Param("item")String item, @Param("itemDescription")String itemDescription);

    List<Map<String,Object>> resourceRepair(@Param("site")String site, @Param("locale")String locale,
                                                @Param("param")Map<String, Object> map);


    List<Map<String, Object>> findInspectionTask(Map paramMap);

    /**
     * 查询质检问题统计表
     * @param paramMap
     * @return
     */
    List<Map<String,Object>> findQualityInspectionReport(Map paramMap);

    List<Map<String,Object>> findAbnormalRecord(Map paramMap);

    /**
     * 工单生产进度报表
     * @param paramMap
     * @return
     */
    List<Map<String,Object>> shopOrderSchedule(Map paramMap);

    /**
     * 操作者加工进度表
     * @param paramMap 参数
     * @return 返回值
     */
    List<Map<String,Object>> findOperatorScheduleReport(Map paramMap);

    /**
     * 工作令加工进度表
     * @param paramMap 参数
     * @return 返回值
     */
    List<Map<String,Object>> findWorkOrderSchedule(Map paramMap);
}
